@@ -18,6 +18,6 @@
 
 #define NL_MAJOR 1
 #define NL_MINOR 0
-#define NL_REV   5
-#define NL_DATE  "Oct 30, 2000"
-#define VERSION  "1.0.5"
+#define NL_REV   7
+#define NL_DATE  "May 14, 2001"
+#define VERSION  "1.0.7"
